Protocol definitions for Hedgehog
=================================

.. image:: https://travis-ci.org/PRIArobotics/HedgehogProtocol.svg?branch=master
    :target: https://travis-ci.org/PRIArobotics/HedgehogProtocol

This project contains protocol definitions for the Hedgehog Educational Robotics Controller.
